@@ -63,7 +63,7 @@ def redirect(path, cookies=False):
 
 def get_response(project_path, method, path, body, http, cookies):
     response_content = get_view(project_path, method, path, body, http, cookies)
-    http_response = re.search(r"HTTP/1.1 {\d+} ")
+    http_response = re.search(r"HTTP/1.1 {\d+} ", response_content)
 
     if http_response:
         return http_response
