@@ -6,8 +6,8 @@ class TableNotFoundError(Exception):
         return self.message
 
 class FieldNotFoundError(Exception):
-    def __init__(self, field_name):
-        self.message = f"Field '{field_name}' does not exist"
+    def __init__(self, field):
+        self.message = f"Field '{field}' does not exist"
     
     def __str__(self):
-        return self.message
+        return self.message
\ No newline at end of file
